@@ -30,7 +30,7 @@
 #' Currently available options are \code{"gaussian"} (squared error), 
 #' \code{"laplace"} (absolute loss), \code{"tdist"} (t-distribution loss), 
 #' \code{"bernoulli"} (logistic regression for 0-1 outcomes), 
-#' \code{"huberized"} (huberized hinge loss for 0-1 outcomes), classes), 
+#' \code{"huberized"} (huberized hinge loss for 0-1 outcomes), 
 #' \code{"adaboost"} (the AdaBoost exponential loss for 0-1 outcomes),
 #' \code{"poisson"} (count outcomes), \code{"coxph"} (right censored 
 #' observations), \code{"quantile"}, or \code{"pairwise"} (ranking measure 
@@ -72,7 +72,7 @@
 #' }
 #' 
 #' \code{ndcg} and \code{conc} allow arbitrary target values, while binary
-#' targets {0,1} are expected for \code{map} and \code{mrr}. For \code{ndcg}
+#' targets \{0,1\} are expected for \code{map} and \code{mrr}. For \code{ndcg}
 #' and \code{mrr}, a cut-off can be chosen using a positive integer parameter
 #' \code{max.rank}. If left unspecified, all ranks are taken into account.
 #' 
@@ -197,7 +197,7 @@
 #' B. Kriegler (2007). Cost-Sensitive Stochastic Gradient Boosting Within a 
 #' Quantitative Regression Framework. Ph.D. Dissertation. University of 
 #' California at Los Angeles, Los Angeles, CA, USA. Advisor(s) Richard A. Berk. 
-#' url{https://dl.acm.org/citation.cfm?id=1354603}.
+#' \url{https://dl.acm.org/doi/book/10.5555/1354603}.
 #' 
 #' C. Burges (2010). \dQuote{From RankNet to LambdaRank to LambdaMART: An
 #' Overview,} Microsoft Research Technical Report MSR-TR-2010-82.
@@ -219,7 +219,7 @@ gbm.fit <- function(x, y, offset = NULL, misc = NULL, distribution = "bernoulli"
   cRows <- nrow(x)
   cCols <- ncol(x)
   
-  if(nrow(x) != ifelse(class(y) == "Surv", nrow(y), length(y))) {
+  if(nrow(x) != ifelse("Surv" %in% class(y), nrow(y), length(y))) {
     stop("The number of rows in x does not equal the length of y.")
   }
   
@@ -311,10 +311,12 @@ gbm.fit <- function(x, y, offset = NULL, misc = NULL, distribution = "bernoulli"
   distribution.call.name <- distribution$name
   
   # Check for potential problems with the distribution
-  if(!is.element(distribution$name,supported.distributions)) {
+  if(!is.element(distribution$name, supported.distributions)) {
     stop("Distribution ",distribution$name," is not supported")
   }
-  if((distribution$name == "bernoulli") && !all(is.element(y,0:1))) {
+  if((distribution$name == "bernoulli") && !all(is.element(y, 0:1)) && 
+     !is.numeric(y)) {
+    # NOTE: Including `!is.numeric(y)` will catch cases where y is a 0/1 factor
     stop("Bernoulli requires the response to be in {0,1}")
     if (is.factor(y)) {
       y <- as.integer(y) - 1
@@ -352,7 +354,7 @@ gbm.fit <- function(x, y, offset = NULL, misc = NULL, distribution = "bernoulli"
     Misc <- c(alpha=distribution$alpha)
   }
   if(distribution$name == "coxph") {
-    if(class(y)!="Surv") {
+    if(!("Surv" %in% class(y))) {
       stop("Outcome must be a survival object Surv(time,failure)")
     }
     if(attr(y,"type")!="right") {
